package org.eclipse.equinox.launcher;

/* loaded from: org_eclipse_equinox_launcher.jar:org/eclipse/equinox/launcher/JNIBridge.class */
public class JNIBridge {
    private String library;
    private boolean libraryLoaded = false;

    private native void _set_exit_data(String str, String str2);

    private native void _update_splash();

    private native long _get_splash_handle();

    private native void _show_splash(String str);

    private native void _takedown_splash();

    private native int OleInitialize(int i);

    private native void OleUninitialize();

    public JNIBridge(String library) {
        this.library = library;
    }

    private void loadLibrary() {
        int idx;
        if (this.library != null) {
            try {
                if (this.library.indexOf("wpf") != -1 && (idx = this.library.indexOf("eclipse_")) != -1) {
                    String comLibrary = String.valueOf(this.library.substring(0, idx)) + "com_";
                    Runtime.getRuntime().load(String.valueOf(comLibrary) + this.library.substring(idx + 8, this.library.length()));
                    OleInitialize(0);
                }
                Runtime.getRuntime().load(this.library);
            } catch (UnsatisfiedLinkError unused) {
            }
        }
        this.libraryLoaded = true;
    }

    public boolean setExitData(String sharedId, String data) {
        try {
            _set_exit_data(sharedId, data);
            return true;
        } catch (UnsatisfiedLinkError unused) {
            if (!this.libraryLoaded) {
                loadLibrary();
                return setExitData(sharedId, data);
            }
            return false;
        }
    }

    public boolean showSplash(String bitmap) {
        try {
            _show_splash(bitmap);
            return true;
        } catch (UnsatisfiedLinkError unused) {
            if (!this.libraryLoaded) {
                loadLibrary();
                return showSplash(bitmap);
            }
            return false;
        }
    }

    public boolean updateSplash() {
        try {
            _update_splash();
            return true;
        } catch (UnsatisfiedLinkError unused) {
            if (!this.libraryLoaded) {
                loadLibrary();
                return updateSplash();
            }
            return false;
        }
    }

    public long getSplashHandle() {
        try {
            return _get_splash_handle();
        } catch (UnsatisfiedLinkError unused) {
            if (!this.libraryLoaded) {
                loadLibrary();
                return getSplashHandle();
            }
            return -1L;
        }
    }

    public boolean takeDownSplash() {
        try {
            _takedown_splash();
            return true;
        } catch (UnsatisfiedLinkError unused) {
            if (!this.libraryLoaded) {
                loadLibrary();
                return takeDownSplash();
            }
            return false;
        }
    }

    public boolean uninitialize() {
        if (this.libraryLoaded && this.library != null && this.library.indexOf("wpf") != -1) {
            try {
                OleUninitialize();
                return true;
            } catch (UnsatisfiedLinkError unused) {
                return false;
            }
        }
        return true;
    }
}
