package org.eclipse.osgi.framework.internal.core;

/* loaded from: org_eclipse_osgi_framework_internal_core.jar:org/eclipse/osgi/framework/internal/core/Tokenizer.class */
public class Tokenizer {
    protected char[] value;
    protected int max;
    protected int cursor = 0;

    public Tokenizer(String value) {
        this.value = value.toCharArray();
        this.max = this.value.length;
    }

    private void skipWhiteSpace() {
        char c;
        char[] val = this.value;
        int cur = this.cursor;
        while (cur < this.max && ((c = val[cur]) == ' ' || c == '\t' || c == '\n' || c == '\r')) {
            cur++;
        }
        this.cursor = cur;
    }

    public String getToken(String terminals) {
        skipWhiteSpace();
        char[] val = this.value;
        int cur = this.cursor;
        while (cur < this.max) {
            char c = val[cur];
            if (terminals.indexOf(c) != -1) {
                break;
            }
            cur++;
        }
        this.cursor = cur;
        int count = cur - cur;
        if (count > 0) {
            skipWhiteSpace();
            while (count > 0 && (val[(cur + count) - 1] == ' ' || val[(cur + count) - 1] == '\t')) {
                count--;
            }
            return new String(val, cur, count);
        }
        return null;
    }

    public String getString(String terminals) {
        skipWhiteSpace();
        char[] val = this.value;
        int cur = this.cursor;
        if (cur < this.max) {
            if (val[cur] == '\"') {
                StringBuffer sb = new StringBuffer();
                int cur2 = cur + 1;
                char c = 0;
                while (cur2 < this.max) {
                    c = val[cur2];
                    if (c == '\\') {
                        cur2++;
                        if (cur2 == this.max) {
                            break;
                        }
                        c = val[cur2];
                        sb.append(c);
                        cur2++;
                    } else {
                        if (c == '\"') {
                            break;
                        }
                        sb.append(c);
                        cur2++;
                    }
                }
                int count = cur2 - cur2;
                if (c == '\"') {
                    cur2++;
                }
                this.cursor = cur2;
                if (count > 0) {
                    skipWhiteSpace();
                    return sb.toString();
                }
                return null;
            }
            return getToken(terminals);
        }
        return null;
    }

    public char getChar() {
        int cur = this.cursor;
        if (cur < this.max) {
            this.cursor = cur + 1;
            return this.value[cur];
        }
        return (char) 0;
    }

    public boolean hasMoreTokens() {
        if (this.cursor < this.max) {
            return true;
        }
        return false;
    }
}
